/*
    NSObject(MAImplementation) - extra NSObject methods
    
    Copyright (C) 1995, Adam Fedor
    
*/

#ifndef __NSObject_MAImplementation_INCLUDE
#define __NSObject_MAImplementation_INCLUDE

#ifndef GNUSTEP
#import <Foundation/Foundation.h>
#else
#include <Foundation/NSObject.h>
#endif

@interface NSObject(MAImplementation)

- (void)maNotImplemented:(SEL)aSelector;
- (void)maSubclassResponsibility:(SEL)aSelector;

@end

#endif
